@@ -1,4 +1,4 @@
-# Copyright (C) 2021,2022,2023,2024 Kian-Meng Ang
+# Copyright (c) 2021,2022,2023,2024,2025 Kian-Meng Ang
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -17,4 +17,4 @@
 
 
 class EmptyFileError(Exception):
-    """Empty file content in txt file."""
+    """Raised when the input file has no content."""
