@@ -1,4 +1,4 @@
-# Copyright (C) 2021,2022,2023,2024 Kian-Meng Ang
+# Copyright (c) 2021,2022,2023,2024,2025 Kian-Meng Ang
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -15,10 +15,6 @@
 
 """Packpage of different e-book formats."""
 
-import argparse
-from typing import Union
-
-import txt2ebook.models.book
 from txt2ebook.formats.epub import TEMPLATES as EPUB_TEMPLATES
 from txt2ebook.formats.epub import EpubWriter
 from txt2ebook.formats.gmi import GmiWriter
@@ -27,7 +23,6 @@ from txt2ebook.formats.pdf import PdfWriter
 from txt2ebook.formats.tex import TexWriter
 from txt2ebook.formats.txt import TxtWriter
 from txt2ebook.formats.typ import TypWriter
-from txt2ebook.helpers import load_class, to_classname
 from txt2ebook.models import Book
 
 EBOOK_FORMATS = ["epub", "gmi", "md", "pdf", "tex", "txt", "typ"]
@@ -51,29 +46,6 @@ PAGE_SIZES = [
     "letter",
 ]
 
-
-def create_format(
-    book: txt2ebook.models.book.Book,
-    ebook_format: str,
-    config: argparse.Namespace,
-) -> Union[TxtWriter, EpubWriter]:
-    """Create ebook formatter by format using factory function.
-
-    Args:
-        book(txt2ebook.models.book.Book): The book model which contains
-        metadata and table of contents of volumes and chapters.
-        ebook_format(str): The ebook format.
-        config(argparse.Namespace): The configs from the command-line.
-
-    Returns:
-        TxtWriter | EpubWriter
-    """
-    class_name = to_classname(ebook_format, "Writer")
-    klass = load_class("txt2ebook.formats", class_name)
-    formatter = klass(book, config)
-    return formatter
-
-
 __all__ = [
     "Book",
     "EBOOK_FORMATS",
