@@ -1,4 +1,4 @@
-# Copyright (C) 2021,2022,2023,2024 Kian-Meng Ang
+# Copyright (c) 2021,2022,2023,2024,2025 Kian-Meng Ang
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -84,8 +84,7 @@ class BaseWriter(ABC):
                 shutil.rmtree(cwd)
             else:
                 answer = input(
-                    "Are you sure to purge output folder: "
-                    f"{cwd.absolute()}? [y/N] "
+                    f"Are you sure to purge output folder: {cwd.absolute()}? [y/N] "
                 )
                 if answer.lower() == "y":
                     logger.debug("Purge output folder: %s", cwd.absolute())
