@@ -1,4 +1,4 @@
-# Copyright (C) 2021,2022,2023,2024 Kian-Meng Ang
+# Copyright (c) 2021,2022,2023,2024,2025 Kian-Meng Ang
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -84,7 +84,7 @@ class GmiWriter(BaseWriter):
                             f"_{txt_filename.stem}"
                             f"_{section.title}"
                             f"_{chapter.title}"
-                            ".md"
+                            ".gmi"
                         )
                     )
 
@@ -102,12 +102,7 @@ class GmiWriter(BaseWriter):
                     ct_seq = ct_seq + 1
             if isinstance(section, Chapter):
                 filename = lower_underscore(
-                    (
-                        f"{section_seq}"
-                        f"_{txt_filename.stem}"
-                        f"_{section.title}"
-                        ".gmi"
-                    )
+                    (f"{section_seq}_{txt_filename.stem}_{section.title}.gmi")
                 )
 
                 export_filename = Path(
@@ -128,12 +123,12 @@ class GmiWriter(BaseWriter):
 
         with open(new_filename, "w", encoding="utf8") as file:
             logger.info("Generate GemText file: %s", new_filename.resolve())
-            file.write(self._to_md())
+            file.write(self._to_gmi())
 
         if self.config.open:
             self._open_file(new_filename)
 
-    def _to_md(self) -> str:
+    def _to_gmi(self) -> str:
         toc = self._to_toc("*", "# ") if self.config.with_toc else ""
         return self._to_metadata_txt() + toc + self._to_body_txt()
 
