@@ -1,4 +1,4 @@
-# Copyright (C) 2021,2022,2023,2024 Kian-Meng Ang
+# Copyright (c) 2021,2022,2023,2024,2025 Kian-Meng Ang
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -101,12 +101,7 @@ class MdWriter(BaseWriter):
                     ct_seq = ct_seq + 1
             if isinstance(section, Chapter):
                 filename = lower_underscore(
-                    (
-                        f"{section_seq}"
-                        f"_{txt_filename.stem}"
-                        f"_{section.title}"
-                        ".md"
-                    )
+                    (f"{section_seq}_{txt_filename.stem}_{section.title}.md")
                 )
 
                 export_filename = Path(
