@@ -1,4 +1,4 @@
-# Copyright (C) 2021,2022,2023,2024 Kian-Meng Ang
+# Copyright (c) 2021,2022,2023,2024,2025 Kian-Meng Ang
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -36,6 +36,11 @@ logger = logging.getLogger(__name__)
 class TypWriter(BaseWriter):
     """Module for writing ebook in Typst (typ) format."""
 
+    def __post_init__(self):
+        """Post init code."""
+        self.index_keywords = self.config.index_keyword + self.book.index
+        logger.debug("Index keywords: %s", self.index_keywords)
+
     def write(self) -> None:
         """Generate Typst files."""
         self._new_file()
@@ -61,7 +66,8 @@ class TypWriter(BaseWriter):
 
     def _to_typ(self) -> str:
         return (
-            self._to_metadata_typ()
+            self._include_packages()
+            + self._to_metadata_typ()
             + self._to_cover()
             + self._to_outline()
             + '#set page(numbering: "1")'
@@ -69,6 +75,15 @@ class TypWriter(BaseWriter):
             + "#counter(page).update(1)"
             + "\n"
             + self._to_body_txt()
+            + self._index_pages()
+        )
+
+    def _include_packages(self) -> str:
+        return textwrap.dedent(
+            """
+                #import "@preview/in-dexter:0.5.3": *
+
+        """
         )
 
     def _to_metadata_typ(self) -> str:
@@ -80,9 +95,10 @@ class TypWriter(BaseWriter):
           numbering: "1",
           number-align: right,
         )
+
         #show heading.where(
           level: 1
-        ): it => block(width: 100%)[
+        ): it => block(width: 100%, below: 1.5em)[
           #set align(center)
           #set text(16pt, weight: "regular")
           #smallcaps(it.body)
@@ -90,20 +106,33 @@ class TypWriter(BaseWriter):
 
         #show heading.where(
           level: 2
-        ): it => block(width: 100%)[
+        ): it => block(width: 100%, below: 1.5em)[
           #set align(center)
           #set text(14pt, weight: "regular")
           #smallcaps(it.body)
         ]
 
         #set par(
+          first-line-indent: (
+            amount: 2em,
+            all:true,
+          ),
           justify: true,
         )
+
         #set text(
           font: "Noto Serif CJK SC",
           size: 12pt,
         )
 
+        #show outline.entry: it => {{
+          text(it, fill: red)
+        }}
+
+        #show link: it => {{
+          text(it, fill: red)
+        }}
+
         """
         )
 
@@ -111,7 +140,8 @@ class TypWriter(BaseWriter):
         return textwrap.dedent(
             f"""
             #set page(paper: "{self._get_pagesize()}", numbering: none)
-            #align(center, text(17pt)[{self.book.title}])
+            #align(center + horizon, text(17pt)[{self.book.title}])
+            #align(center + horizon, text(17pt)[{", ".join(self.book.authors)}])
             #pagebreak()
 
         """
@@ -122,7 +152,7 @@ class TypWriter(BaseWriter):
             textwrap.dedent(
                 f"""
             #set page(paper: "{self._get_pagesize()}", numbering: none)
-            #outline(title: [目录], indent: 2em,)
+            #outline(title: [目录], indent: 1em)
             #pagebreak()
             """
             )
@@ -157,14 +187,37 @@ class TypWriter(BaseWriter):
         return (
             f"{header} {chapter.title}"
             + self.config.paragraph_separator
-            + self.config.paragraph_separator.join(chapter.paragraphs)
-            + "#pagebreak()"
+            + self._process_paragraphs(chapter.paragraphs)
+            + "\n#pagebreak()\n"
         )
 
     def _to_volume_chapter_txt(self, volume, chapter) -> str:
         return (
             f"= {volume.title} {chapter.title}"
             + self.config.paragraph_separator
-            + self.config.paragraph_separator.join(chapter.paragraphs)
-            + "#pagebreak()"
+            + self._process_paragraphs(chapter.paragraphs)
+            + "\n#pagebreak()\n"
+        )
+
+    def _process_paragraphs(self, paragraphs) -> str:
+        pars = []
+        for paragraph in paragraphs:
+            par = paragraph.strip()
+            for keyword in self.index_keywords:
+                replace = rf"#index[{keyword}]#link(<index>)[{keyword}]"
+                par = par.replace(keyword, replace)
+            pars.append(par)
+
+        return self.config.paragraph_separator.join(pars)
+
+    def _index_pages(self) -> str:
+        return textwrap.dedent(
+            """
+            = 目录 <index>
+
+            #set text(size: 8pt)
+            #columns(3)[
+                #make-index(outlined: false, use-page-counter: false)
+            ]
+        """
         )
