@@ -1,4 +1,4 @@
-# Copyright (C) 2021,2022,2023,2024 Kian-Meng Ang
+# Copyright (c) 2021,2022,2023,2024,2025 Kian-Meng Ang
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -17,7 +17,8 @@
 
 DEFAULT_RE_TITLE = r"Title:(.*)"
 DEFAULT_RE_AUTHOR = r"Author:(.*)"
-DEFAULT_RE_TAG = r"Tags：(.*)"
-DEFAULT_RE_INDEX = r"Index：(.*)"
+DEFAULT_RE_TAG = r"Tags:(.*)"
+DEFAULT_RE_INDEX = r"Index:(.*)"
 DEFAULT_RE_VOLUME = r"(Volume.*)"
 DEFAULT_RE_CHAPTER = r"(Chapter.*)"
+DEFAULT_RE_TRANSLATOR = r"Translator:(.*)"
