@@ -1,4 +1,4 @@
-# Copyright (C) 2021,2022,2023,2024 Kian-Meng Ang
+# Copyright (c) 2021,2022,2023,2024,2025 Kian-Meng Ang
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -37,7 +37,6 @@ RE_CHAPTERS = [
     "(?:内容)?简介",
     "外篇.*",
     "[号番]外[篇]?.*",
-    "尾声",
     "终章.*",
     "后记.*",
     "文案.*",
@@ -45,8 +44,8 @@ RE_CHAPTERS = [
     "人物[介绍简介设定].*",
     "作者[介绍自介].*",
     "正文",
-    "后记",
     "人物谱",
+    "作者按",
 ]
 
 DEFAULT_RE_AUTHOR = r"作者：(.*)"
