@@ -1,4 +1,4 @@
-# Copyright (C) 2021,2022,2023,2024 Kian-Meng Ang
+# Copyright (c) 2021,2022,2023,2024,2025 Kian-Meng Ang
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -17,11 +17,10 @@
 
 import argparse
 import logging
-from dataclasses import dataclass, field
-from importlib import import_module
+from dataclasses import dataclass
+from types import ModuleType
 from typing import List, Tuple, Union
 
-import cjkwrap
 import regex as re
 
 from txt2ebook.models import Book, Chapter, Volume
@@ -35,16 +34,20 @@ logger = logging.getLogger(__name__)
 class Parser:
     """Parser class to massage and parse a text content."""
 
-    raw_content: str = field()
-    config: argparse.Namespace = field()
+    raw_content: str
+    config: argparse.Namespace
+    langconf: ModuleType
 
-    def __init__(self, raw_content: str, config: argparse.Namespace) -> None:
+    def __init__(
+        self,
+        raw_content: str,
+        config: argparse.Namespace,
+        langconf: ModuleType,
+    ) -> None:
         """Set the constructor for the Parser."""
         self.raw_content = raw_content
         self.config = config
-
-        config_lang = config.language.replace("-", "_")
-        self.langconf = import_module(f"txt2ebook.languages.{config_lang}")
+        self.langconf = langconf
 
     def parse(self) -> Book:
         """Parse the content into volumes (optional) and chapters.
@@ -65,7 +68,7 @@ class Parser:
             translators=translators,
             tags=tags,
             index=index,
-            cover=self.config.cover,
+            cover=getattr(self.config, "cover", ""),
             raw_content=self.raw_content,
             toc=toc,
         )
@@ -88,7 +91,9 @@ class Parser:
         Returns:
             str: The formatted section header.
         """
-        if not self.config.header_number or self.config.language not in (
+        if not getattr(
+            self.config, "header_number", False
+        ) or self.config.language not in (
             "zh-cn",
             "zh-tw",
         ):
@@ -112,7 +117,7 @@ class Parser:
 
         replaced_words = zh_words_to_numbers(words, length=length)
 
-        if self.config.fullwidth:
+        if hasattr(self.config, "fullwidth") and self.config.fullwidth:
             replaced_words = zh_halfwidth_to_fullwidth(replaced_words)
 
         logger.debug(
@@ -209,21 +214,22 @@ class Parser:
                         toc.append(current_chapter)
 
             if token.type == "PARAGRAPH":
-                if toc and isinstance(toc[-1], Volume):
-                    toc[-1].chapters[-1].add_paragraph(token.value)
+                if toc:
+                    if isinstance(toc[-1], Volume):
+                        toc[-1].chapters[-1].add_paragraph(token.value)
 
-                if toc and isinstance(toc[-1], Chapter):
-                    toc[-1].add_paragraph(token.value)
+                    if isinstance(toc[-1], Chapter):
+                        toc[-1].add_paragraph(token.value)
 
         # Use authors if set explicitly from command line.
-        if self.config.author:
+        if hasattr(self.config, "author") and self.config.author:
             authors = self.config.author
 
-        if self.config.title:
+        if hasattr(self.config, "title") and self.config.title:
             book_title = self.config.title
 
-        if self.config.translator:
-            authors = self.config.translator
+        if hasattr(self.config, "translator") and self.config.translator:
+            translators = self.config.translator
 
         logger.info("Found or set book title: %s", book_title)
         logger.info("Found or set authors: %s", repr(authors))
@@ -231,7 +237,10 @@ class Parser:
         logger.info("Found or set tags: %s", repr(tags))
         logger.info("Found or set index: %s", repr(index))
 
-        if self.config.sort_volume_and_chapter:
+        if (
+            hasattr(self.config, "sort_volume_and_chapter")
+            and self.config.sort_volume_and_chapter
+        ):
             self.sort_volume_and_chapter(toc)
 
         return (book_title, authors, translators, tags, index, toc)
