@@ -1,4 +1,4 @@
-# Copyright (C) 2021,2022,2023,2024 Kian-Meng Ang
+# Copyright (c) 2021,2022,2023,2024,2025 Kian-Meng Ang
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -62,11 +62,7 @@ class Tokenizer:
         """Set the constructor for the Tokenizer."""
         self.raw_content = raw_content
         self.config = config
-
-        if self.config.fullwidth:
-            self.metadata_marker = "－－－"
-        else:
-            self.metadata_marker = "---"
+        self.metadata_marker = "---"
 
         config_lang = config.language.replace("-", "_")
         self.langconf = import_module(f"txt2ebook.languages.{config_lang}")
@@ -118,11 +114,11 @@ class Tokenizer:
         """Tokenize the metadata of the book."""
         for line in self._extract_metadata():
             re_title = f"^{self.langconf.DEFAULT_RE_TITLE}"
-            if self.config.re_title:
+            if hasattr(self.config, "re_title") and self.config.re_title:
                 re_title = self.config.re_title[0]
 
             re_author = f"{self.langconf.DEFAULT_RE_AUTHOR}"
-            if self.config.re_author:
+            if hasattr(self.config, "re_author") and self.config.re_author:
                 re_author = self.config.re_author[0]
 
             token_type_regex_map = [
@@ -174,11 +170,27 @@ class Tokenizer:
         return metadata
 
     def _tokenize_content(self) -> None:
-        content = self.raw_content.split(f"{self.metadata_marker}\n\n")[1]
-        content = content.strip(self.config.paragraph_separator)
-        lines = content.split(self.config.paragraph_separator)
+        # Determine the actual content part, after any metadata block
+        metadata_block_re = (
+            rf"^(?:{self.metadata_marker})\n(.*)\n(?:{self.metadata_marker})$"
+        )
+        match = re.search(
+            metadata_block_re, self.raw_content, re.MULTILINE | re.DOTALL
+        )
 
-        if len(lines) <= 1:
+        if match:
+            # Content starts after the matched metadata block
+            content_str = self.raw_content[match.end(0) :]
+        else:
+            # No metadata block found according to the pattern,
+            # so assume all raw_content is the actual content.
+            # _extract_metadata would have already logged/warned if metadata was expected.
+            content_str = self.raw_content
+
+        content_str = content_str.strip(self.config.paragraph_separator)
+        lines = content_str.split(self.config.paragraph_separator)
+
+        if len(lines) <= 1 and content_str:  # Avoid warning for empty content
             msg = (
                 "Cannot split content by "
                 f"{repr(self.config.paragraph_separator)}. "
@@ -209,7 +221,10 @@ class Tokenizer:
             rf"^{self.langconf.DEFAULT_RE_VOLUME}\s*"
             rf"{self.langconf.DEFAULT_RE_CHAPTER}"
         )
-        if self.config.re_volume_chapter:
+        if (
+            hasattr(self.config, "re_volume_chapter")
+            and self.config.re_volume_chapter
+        ):
             re_volume_chapter = self.config.re_volume_chapter[0]
 
         match = re.search(re_volume_chapter, line)
@@ -232,7 +247,7 @@ class Tokenizer:
         token = None
 
         re_volume = rf"^{self.langconf.DEFAULT_RE_VOLUME}$"
-        if self.config.re_volume:
+        if hasattr(self.config, "re_volume") and self.config.re_volume:
             re_volume = "(" + "|".join(self.config.re_volume) + ")"
 
         match = re.search(re_volume, line)
@@ -248,7 +263,7 @@ class Tokenizer:
         token = None
 
         re_chapter = rf"^{self.langconf.DEFAULT_RE_CHAPTER}$"
-        if self.config.re_chapter:
+        if hasattr(self.config, "re_chapter") and self.config.re_chapter:
             re_chapter = "(" + "|".join(self.config.re_chapter) + ")"
 
         match = re.search(re_chapter, line)
